@@ -66,6 +66,34 @@ static void remove_from_network_monitor (ClockLocation *loc);
 
 #define PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), CLOCK_LOCATION_TYPE, ClockLocationPrivate))
 
+ClockLocation *
+clock_location_find_and_ref (GList       *locations,
+                             const gchar *name,
+                             const gchar *timezone,
+                             gfloat       latitude,
+                             gfloat       longitude,
+                             const gchar *code)
+{
+        GList *l;
+        ClockLocationPrivate *priv;
+
+        for (l = locations; l != NULL; l = l->next) {
+                priv = PRIVATE (l->data);
+
+                if (priv->latitude == latitude &&
+                    priv->longitude == longitude &&
+                    g_strcmp0 (priv->weather_code, code) == 0 &&
+                    g_strcmp0 (priv->timezone, timezone) == 0 &&
+                    g_strcmp0 (priv->name, name) == 0)
+                        break;
+        }
+
+        if (l != NULL)
+                return g_object_ref (CLOCK_LOCATION (l->data));
+        else
+                return NULL;
+}
+
 ClockLocation *
 clock_location_new (const gchar *name, const gchar *timezone,
 		    gfloat latitude, gfloat longitude,
@@ -458,7 +486,8 @@ free_make_current_data (gpointer data)
 }
 
 void
-clock_location_make_current (ClockLocation *loc, 
+clock_location_make_current (ClockLocation *loc,
+			     guint          transient_parent_xid,
                              GFunc          callback,
                              gpointer       data,
                              GDestroyNotify destroy)
@@ -467,6 +496,12 @@ clock_location_make_current (ClockLocation *loc,
         gchar *filename;
 	MakeCurrentData *mcdata;
 
+        if (loc == current_location) {
+                if (destroy)
+                        destroy (data);
+                return;
+        }
+
 	if (clock_location_is_current_timezone (loc)) {
 		if (current_location)
 			g_object_remove_weak_pointer (G_OBJECT (current_location), 
@@ -491,7 +526,8 @@ clock_location_make_current (ClockLocation *loc,
 	mcdata->destroy = destroy;
 
         filename = g_build_filename (SYSTEM_ZONEINFODIR, priv->timezone, NULL);
-        set_system_timezone_async (filename, 
+        set_system_timezone_async (filename,
+				   transient_parent_xid,
                                    (GFunc)make_current_cb, 
 				   mcdata,
                                    free_make_current_data);
